<?php
/*
Plugin Name: Etracker Pro
Plugin URI: https://etrackerpro.com
Description: Etracker Pro generates a session id for your website visitors. Matches this id with your Google Analytics data, orders and leads. 
Version: 1.1
Author: Optimum7
Author URI: https://optimum7.com
*/

//import etracker main class
include 'src/etracker.class.php';

//create new instance
$etracker = new Erackerpro_Admin;

# defined etracker remote app url if not
if( ! defined('ETRACKER_REMOTE_URL') )
{
    define('ETRACKER_REMOTE_URL' , 'https://app.etrackerpro.com/');
}


#add admin menu
add_action('admin_menu', 'etracker_menu');
function etracker_menu()
{
    add_menu_page('Etracker Pro','Etracker Pro', 'manage_options', 'etrackerpro', 'etrackerpro_index');
}

#add admin ui styles
add_action('admin_enqueue_scripts', 'etracker_scripts'); 
function etracker_scripts() 
{
    if( is_admin() )
    { 
        wp_enqueue_style('admin_js_bootstrap', plugins_url('assets/style.css', __FILE__ ),false,'0.1',false);
    } 
}    



#cleanliness is faith
register_deactivation_hook( __FILE__, 'etracker_deactived');
function etracker_deactived()
{
    delete_option('etracker_authorized');
    delete_option('etracker_uniqid');
}



function etrackerpro_index()
{
    global $etracker;

    $action = sanitize_text_field( $_GET['action'] );
    
    if(empty($action))
    {
        $action = 'index';
    }

    //check etracker is authorized 
    $etracker_authorized = get_option('etracker_authorized');

    //uniqid for tthis domain
    $uniqid = get_option('etracker_uniqid');

    //check domain if added to etracker app
    $check_domain = $etracker->check_domain();

    // required plugin
    if(! $etracker->is_woocommerce_active())
    {
        $etracker->view('error', [
            'error' => 'This plugin need woocommerce!'
        ]);
    }
   
    //main page
    if($action == 'index')
    {
        if($etracker_authorized == false)
        {
            $etracker->view('authorize' , ['url' => $etracker->authorize_url()]);
        }
        else
        {
            //if etracker autthorized and domain not found 
            if(!$check_domain){
                $etracker->redirect_to_authoized();
            }

            $etracker->view('index' , [
                'url' => $etracker->return_setup_url(0),
                'reAuth' => $etracker->authorize_url()
            ]);
        }
        
        return;
    }
 


    if($action == 'authorize')
    {
        $success = sanitize_text_field($_GET['success']);

        if($success != "1")
        {
            $success = 0;
        }

        if(!$success)
        {
            $etracker->view('error' , ['error' => 'Etracker Pro install cancelled!']);
            return;
        }

        //if auth flow successed
        $etracker->add_or_update_option('etracker_authorized' , 'yes');

        //get & set uniqid as option
        $uniqid = $etracker->set_uniqid();

        $etracker->view('authorized' , [
            'uniqid' => $uniqid , 
            'url' => $etracker->return_setup_url($uniqid),
            'checkDomain' => $check_domain
        ]);
    }
  
}

//
$uniqid = get_option('etracker_uniqid');

if( $uniqid !== false )
{
    add_action( 'wp_enqueue_scripts', 'etracker_script_load' );

    function etracker_script_load()
    {
        global $etracker, $uniqid;
        wp_enqueue_script( 'etracker-pro', $etracker->script_url($uniqid) );
    }
}